@@ -29,10 +29,10 @@
 #include <stddef.h>
 #include <limits>
 #include <map>
+#include <memory>
 #include <string>
 #include <utility>
 #include <vector>
-
 #include <unicode/uchar.h>
 
 #include "phonenumbers/alternate_format.h"
@@ -51,6 +51,7 @@
 #include "phonenumbers/regexp_adapter_icu.h"
 #include "phonenumbers/regexp_cache.h"
 #include "phonenumbers/stringutil.h"
+#include "phonenumbers/utf/unicodetext.h"
 
 #ifdef I18N_PHONENUMBERS_USE_RE2
 #include "phonenumbers/regexp_adapter_re2.h"
@@ -406,7 +407,9 @@ PhoneNumberMatcher::PhoneNumberMatcher(const PhoneNumberUtil& util,
       max_tries_(max_tries),
       state_(NOT_READY),
       last_match_(NULL),
-      search_index_(0) {
+      search_index_(0),
+      is_input_valid_utf8_(true) {
+  is_input_valid_utf8_ = IsInputUtf8(); 
 }
 
 PhoneNumberMatcher::PhoneNumberMatcher(const string& text,
@@ -420,12 +423,20 @@ PhoneNumberMatcher::PhoneNumberMatcher(const string& text,
       max_tries_(numeric_limits<int>::max()),
       state_(NOT_READY),
       last_match_(NULL),
-      search_index_(0) {
+      search_index_(0),
+      is_input_valid_utf8_(true) {
+  is_input_valid_utf8_ =  IsInputUtf8();
 }
 
 PhoneNumberMatcher::~PhoneNumberMatcher() {
 }
 
+bool PhoneNumberMatcher::IsInputUtf8() {
+  UnicodeText number_as_unicode;
+  number_as_unicode.PointToUTF8(text_.c_str(), text_.size());
+  return number_as_unicode.UTF8WasValid();
+}
+
 // static
 bool PhoneNumberMatcher::IsLatinLetter(char32 letter) {
   // Combining marks are a subset of non-spacing-mark.
@@ -572,8 +583,8 @@ bool PhoneNumberMatcher::ExtractInnerMatch(const string& candidate, int offset,
     string group;
     while ((*regex)->FindAndConsume(candidate_input.get(), &group) &&
            max_tries_ > 0) {
-      int group_start_index = candidate.length() -
-          candidate_input->ToString().length() - group.length();
+      int group_start_index = static_cast<int>(candidate.length() -
+          candidate_input->ToString().length() - group.length());
       if (is_first_match) {
         // We should handle any group before this one too.
         string first_group_only = candidate.substr(0, group_start_index);
@@ -625,6 +636,11 @@ bool PhoneNumberMatcher::ExtractMatch(const string& candidate, int offset,
 }
 
 bool PhoneNumberMatcher::HasNext() {
+  // Input should contain only UTF-8 characters.
+  if (!is_input_valid_utf8_) {
+    state_ = DONE;
+    return false;
+  }
   if (state_ == NOT_READY) {
     PhoneNumberMatch temp_match;
     if (!Find(search_index_, &temp_match)) {
@@ -660,7 +676,7 @@ bool PhoneNumberMatcher::Find(int index, PhoneNumberMatch* match) {
   string candidate;
   while ((max_tries_ > 0) &&
          reg_exps_->pattern_->FindAndConsume(text.get(), &candidate)) {
-    int start = text_.length() - text->ToString().length() - candidate.length();
+    int start = static_cast<int>(text_.length() - text->ToString().length() - candidate.length());
     // Check for extra numbers at the end.
     reg_exps_->capture_up_to_second_number_start_pattern_->
         PartialMatch(candidate, &candidate);
@@ -668,7 +684,7 @@ bool PhoneNumberMatcher::Find(int index, PhoneNumberMatch* match) {
       return true;
     }
 
-    index = start + candidate.length();
+    index = static_cast<int>(start + candidate.length());
     --max_tries_;
   }
   return false;
@@ -822,9 +838,9 @@ bool PhoneNumberMatcher::AllNumberGroupsAreExactlyPresent(
   }
 
   // Set this to the last group, skipping it if the number has an extension.
-  int candidate_number_group_index =
+  int candidate_number_group_index = static_cast<int>(
       phone_number.has_extension() ? candidate_groups.size() - 2
-                                   : candidate_groups.size() - 1;
+                                   : candidate_groups.size() - 1);
   // First we check if the national significant number is formatted as a block.
   // We use find and not equals, since the national significant number may be
   // present with a prefix such as a national number prefix, or the country code
@@ -840,7 +856,7 @@ bool PhoneNumberMatcher::AllNumberGroupsAreExactlyPresent(
   // Starting from the end, go through in reverse, excluding the first group,
   // and check the candidate and number groups are the same.
   for (int formatted_number_group_index =
-           (formatted_number_groups.size() - 1);
+           static_cast<int>(formatted_number_groups.size() - 1);
        formatted_number_group_index > 0 &&
        candidate_number_group_index >= 0;
        --formatted_number_group_index, --candidate_number_group_index) {
